import os
import json
import logging
from dotenv import load_dotenv
from utils import preprocess_stock_data, analyze_stock_data, fetch_and_save_stock_data

logging.basicConfig(level=logging.INFO)

# Load environment variables from the .env file
env_path = r'C:/Users/user/projects/st/.env'
load_dotenv(dotenv_path=env_path)

# Function to load configuration
def load_config(config_path):
    logging.info("Loading configuration")
    with open(config_path, 'r') as file:
        return json.load(file)

# Load token
def load_token(token_path):
    logging.info("Loading token")
    with open(token_path, 'r') as file:
        return json.load(file)

# Load configuration and token
config = load_config(r'C:/Users/user/KIS/config/config.json')
token = load_token(r'C:/Users/user/KIS/config/token.json')

# Replace placeholders with actual values
def replace_placeholders(config):
    logging.info("Replacing placeholders with actual values")
    config['my_agent'] = os.getenv('MY_AGENT', config['my_agent'])
    config['my_app'] = os.getenv('MY_APP', config['my_app'])
    config['my_sec'] = os.getenv('MY_SEC', config['my_sec'])
    config['my_acct_stock'] = os.getenv('MY_ACCT_STOCK', config['my_acct_stock'])
    config['my_prod'] = os.getenv('MY_PROD', config['my_prod'])
    config['prod'] = os.getenv('PROD_URL', config['prod'])
    config['user_id'] = os.getenv('USER_ID', config['user_id'])
    config['kis_devlp.yaml']['my_token'] = token['token']

replace_placeholders(config)

# Define the initialize function
def initialize():
    logging.info("Initializing the system")
    # Add any initialization code here

# Define the process_stocks function
def process_stocks(stock_code, start_date, end_date):
    logging.info(f"Processing stocks: {stock_code} from {start_date} to {end_date}")
    try:
        logging.info("Fetching and saving stock data")
        file_name = fetch_and_save_stock_data(stock_code, start_date, end_date)
        logging.info(f"Stock data saved to {file_name}")

        logging.info("Preprocessing stock data")
        df = preprocess_stock_data(file_name)
        logging.info("Stock data preprocessed")

        logging.info("Analyzing stock data")
        analyze_stock_data(df)
        logging.info("Stock data analysis complete")

        logging.info("Stock processing complete")
    except Exception as e:
        logging.error(f"Error processing stocks: {e}")
        raise

# Make sure to expose these functions for import
__all__ = ['initialize', 'process_stocks']
