import os
import sys
import pandas as pd
from dotenv import load_dotenv
import backtrader as bt
from KoreaInvestmentAPI import KoreaInvestmentAPI
from strategy import AdvancedAdaptiveStrategy
from q_learning import QLearningAgent
import yfinance as yf

# Ensure the current directory is in the sys.path
sys.path.append(os.path.abspath(os.path.dirname(__file__)))

# Load environment variables from .env file
load_dotenv()

# Initialize global variable to control trading
trading_active = False

# API Initialization
api = KoreaInvestmentAPI()

def start_trading():
    global trading_active
    trading_active = True

    # Retrieve search conditions
    conditions = api.get_search_conditions()
    if conditions:
        print("Search Conditions:", conditions)

        # List of condition names to test
        condition_names = [condition['condition_nm'] for condition in conditions['output2']]

        # Initialize Q-learning agent
        agent = QLearningAgent(condition_names)

        # Initial state
        state = 'initial'

        for episode in range(100):  # Number of episodes
            if not trading_active:
                break
            action = agent.choose_action(state)
            my_sec = action
            seq = None
            for condition in conditions['output2']:
                if condition['condition_nm'] == my_sec:
                    seq = condition['seq']
                    break

            if seq:
                print(f"Using seq: {seq} for search results")
                results = api.get_search_results(seq)
                print(f"Search Results Structure: {results}")

                if results:
                    print(f"Search Results for {my_sec}:", results)

                    # Extract necessary fields from results
                    if 'output2' in results and len(results['output2']) > 0:
                        # Extracting specific fields from results
                        dates = pd.date_range(start='1/1/2020', periods=len(results['output2']))
                        prices = [float(item['price'].strip()) for item in results['output2']]
                        # Here you can implement trading logic based on the extracted data

def stop_trading():
    global trading_active
    trading_active = False

def collect_data():
    try:
        # Retrieve search conditions and select stocks for learning
        conditions = api.get_search_conditions()
        if not conditions:
            logging.error("No search conditions available.")
            return

        selected_stocks = []
        for condition in conditions['output2']:
            seq = condition['seq']
            results = api.get_search_results(seq)
            if 'output2' in results:
                for item in results['output2']:
                    selected_stocks.append(item['symbol'])

        if not selected_stocks:
            logging.error("No stocks found from search conditions.")
            return

        end_date = pd.to_datetime('today').strftime('%Y-%m-%d')
        start_date = (pd.to_datetime('today') - pd.DateOffset(years=5)).strftime('%Y-%m-%d')

        for stock in selected_stocks:
            data = yf.download(stock, start=start_date, end=end_date)
            data.to_csv(os.path.join(os.path.dirname(__file__), 'data', f'{stock}_5years.csv'))

        logging.info("Data collection for learning completed")
    except Exception as e:
        logging.error("Error collecting data: %s", e)


def run_analysis():
    data_folder = 'data'
    files = [f for f in os.listdir(data_folder) if f.endswith('_5years.csv')]

    for file in files:
        data = pd.read_csv(os.path.join(data_folder, file), index_col='Date', parse_dates=True)
        env = StockTradingEnv(data)

        actions = list(range(3))  # Buy, Hold, Sell
        agent = QLearningAgent(actions)

        for episode in range(100):
            state = env.reset()
            while True:
                action = agent.choose_action(str(state))
                next_state, reward, done = env.step(action)
                agent.learn(str(state), action, reward, str(next_state))
                state = next_state
                if done:
                    break

    print("Analysis and training completed")
