document.addEventListener("DOMContentLoaded", function() {
    const socket = io.connect(location.protocol + '//' + document.domain + ':' + location.port);

    socket.on('investmentAmountUpdateSuccess', function(data) {
        console.log('Success:', data);
        alert('Investment amount updated successfully');
    });

    socket.on('investmentAmountUpdateFailed', function(data) {
        console.error('Update failed:', data.error);
        alert('Error: ' + data.error);
    });

    document.getElementById('investment-amount').addEventListener('input', function(event) {
        try {
            let investmentAmount = event.target.value.replace(/,/g, '');
            if (!isNaN(investmentAmount) && investmentAmount !== '') {
                investmentAmount = parseInt(investmentAmount);
                event.target.value = formatNumberWithCommas(investmentAmount);
                socket.emit('updateInvestmentAmount', { investmentAmount: investmentAmount });
            } else {
                event.target.value = '';
            }
        } catch (error) {
            console.error('Error updating investment amount:', error);
            alert('Error updating investment amount');
        }
    });

    document.getElementById('start-trading').addEventListener('click', function() {
        try {
            socket.emit('startTrading');
            alert('자동매매가 시작되었습니다.');
        } catch (error) {
            console.error('Error starting trading:', error);
            alert('Error starting trading');
        }
    });

    document.getElementById('stop-trading').addEventListener('click', function() {
        try {
            socket.emit('stopTrading');
            alert('자동매매가 중지되었습니다.');
        } catch (error) {
            console.error('Error stopping trading:', error);
            alert('Error stopping trading');
        }
    });

    document.getElementById('risk-level').addEventListener('input', function() {
        try {
            const riskValue = this.value;
            document.getElementById('risk-value').innerText = riskValue;
            updateRiskLevel(riskValue);
        } catch (error) {
            console.error('Error updating risk level:', error);
            alert('Error updating risk level');
        }
    });

    function updateRiskLevel(riskValue) {
        try {
            console.log('Risk level set to:', riskValue);
            socket.emit('updateRiskLevel', { riskLevel: riskValue });
        } catch (error) {
            console.error('Error updating risk level:', error);
            alert('Error updating risk level');
        }
    }

    function formatNumberWithCommas(number) {
        return number.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ",");
    }
});
