
import gym
from gym import spaces
import numpy as np
import pandas as pd

class StockTradingEnv(gym.Env):
    metadata = {'render.modes': ['human']}

    def __init__(self, df):
        super(StockTradingEnv, self).__init__()

        self.df = df
        self.reward_range = (0, np.inf)

        # Actions of the format Buy x%, Sell x%, Hold, etc.
        self.action_space = spaces.Discrete(3)

        # Prices contains the OHCL values
        self.observation_space = spaces.Box(low=0, high=1, shape=(len(df.columns),), dtype=np.float16)

    def _next_observation(self):
        frame = np.array([
            self.df.loc[self.current_step, 'open'] / self.max_price,
            self.df.loc[self.current_step, 'high'] / self.max_price,
            self.df.loc[self.current_step, 'low'] / self.max_price,
            self.df.loc[self.current_step, 'close'] / self.max_price,
        ])
        return frame

    def _take_action(self, action):
        current_price = self.df.loc[self.current_step, "close"]
        if action == 0:  # Buy
            self.balance -= current_price
            self.shares += 1
        elif action == 1:  # Sell
            self.balance += current_price
            self.shares -= 1

        self.total_value = self.balance + self.shares * current_price

    def step(self, action):
        self._take_action(action)

        self.current_step += 1

        if self.current_step >= len(self.df) - 1:
            self.current_step = 0  # Episode ends

        reward = self.total_value
        done = self.balance <= 0

        obs = self._next_observation()
        return obs, reward, done, {}

    def reset(self):
        self.balance = 1000
        self.shares = 0
        self.total_value = 1000
        self.current_step = 0
        self.max_price = self.df.max().max()

        return self._next_observation()

    def render(self, mode='human', close=False):
        profit = self.total_value - 1000
        print(f'Step: {self.current_step}, Balance: {self.balance}, Shares: {self.shares}, Total Value: {self.total_value}, Profit: {profit}')
