import yaml
import os
from dotenv import load_dotenv

class ConfigManager:
    def __init__(self, config_path, env_path):
        self.config_path = config_path
        self.env_path = env_path
        self.config = self.load_config()
        self.load_env()

    def load_config(self):
        with open(self.config_path, 'r') as file:
            return yaml.safe_load(file)

    def load_env(self):
        load_dotenv(self.env_path)

    def get(self, key, default=None):
        return self.config.get(key, os.getenv(key, default))

def parse_mst_file(file_path, encoding='ISO-8859-1'):
    with open(file_path, 'r', encoding=encoding) as file:
        lines = file.readlines()

    parsed_data = []
    for line in lines:
        record = {
            'code': line[0:6].strip(),
            'isin': line[7:19].strip(),
            'name': line[20:60].strip(),
            'type': line[61:63].strip(),
            'status': line[64:76].strip()
        }
        parsed_data.append(record)

    return parsed_data
