import os
import json
import hmac
import hashlib
import uuid
import socket
import yaml
import requests
from flask import current_app as app

def update_system_status(status_message):
    global system_status
    system_status["status_message"] = status_message
    app.logger.info(f"System status updated: {status_message}")

def get_mac_address():
    mac = ':'.join(['{:02x}'.format((uuid.getnode() >> elements) & 0xff) for elements in range(0, 2*6, 2)][::-1])
    return mac

def get_ip_address():
    hostname = socket.gethostname()
    ip_addr = socket.gethostbyname(hostname)
    return ip_addr

def generate_hashkey(request_body):
    appsecret = os.getenv('PROD_APPSECRET')
    json_body = json.dumps(request_body, separators=(',', ':'))
    secret_key = appsecret.encode()
    hashkey = hmac.new(secret_key, json_body.encode(), hashlib.sha256).hexdigest()
    return hashkey

def get_access_token(config):
    domain = config['api_config']['auth']['domain']
    url = domain + config['api_config']['auth']['url']
    headers = {
        'Content-Type': config['api_config']['auth']['headers']['content-type'],
        'appkey': config['api_config']['auth']['appkey'],
        'appsecret': config['api_config']['auth']['appsecret'],
    }
    data = {
        'grant_type': 'client_credentials',
        'appkey': config['api_config']['auth']['appkey'],
        'appsecret': config['api_config']['auth']['appsecret']
    }
    response = requests.post(url, headers=headers, data=json.dumps(data))
    response.raise_for_status()
    return response.json().get('access_token')

def load_yaml_settings(file_path):
    with open(file_path, 'r') as file:
        return yaml.safe_load(file)

def save_yaml_settings(file_path, settings):
    with open(file_path, 'w') as file:
        yaml.safe_dump(settings, file)

def load_env_settings(file_path):
    env_settings = {}
    with open(file_path, 'r') as file:
        for line in file:
            key, value = line.strip().split('=', 1)
            env_settings[key] = value
    return env_settings

def save_env_settings(file_path, settings):
    with open(file_path, 'w') as file:
        for key, value in settings.items():
            file.write(f"{key}={value}\n")
