import pandas as pd
import plotly.graph_objects as go
import dash
from dash import dcc, html
from dash.dependencies import Input, Output

# Load historical data
def load_data(filepath):
    return pd.read_csv(filepath)

# Create performance dashboard
def create_dashboard(data):
    app = dash.Dash(__name__)

    app.layout = html.Div([
        html.H1("Trading Strategy Performance Dashboard"),
        dcc.Graph(id='price-chart'),
        dcc.Interval(
            id='interval-component',
            interval=60*1000,  # in milliseconds
            n_intervals=0
        )
    ])

    @app.callback(Output('price-chart', 'figure'),
                  Input('interval-component', 'n_intervals'))
    def update_chart(n):
        fig = go.Figure()
        fig.add_trace(go.Scatter(x=data['date'], y=data['price'], mode='lines', name='Price'))
        fig.add_trace(go.Scatter(x=data['date'], y=data['short_mavg'], mode='lines', name='Short Moving Avg'))
        fig.add_trace(go.Scatter(x=data['date'], y=data['long_mavg'], mode='lines', name='Long Moving Avg'))
        fig.update_layout(title='Price and Moving Averages',
                          xaxis_title='Date',
                          yaxis_title='Price')
        return fig

    return app

# Example usage
if __name__ == "__main__":
    df = load_data('historical_stock_data.csv')
    df['date'] = pd.to_datetime(df['date'])
    df['short_mavg'] = df['price'].rolling(window=40, min_periods=1).mean()
    df['long_mavg'] = df['price'].rolling(window=100, min_periods=1).mean()
    app = create_dashboard(df)
    app.run_server(debug=True)
