from flask import Flask, request, jsonify, render_template
from flask_socketio import SocketIO
import threading
import main
import logging
from datetime import datetime

logging.basicConfig(level=logging.INFO)

app = Flask(__name__)
socketio = SocketIO(app)
trading_thread = None

@app.route('/')
def index():
    return render_template('index.html')

@app.route('/initialize', methods=['GET'])
def init_system():
    main.initialize()
    return jsonify({"message": "시스템 초기화 완료"})

@app.route('/start_trading', methods=['POST'])
def start_trading():
    global trading_thread
    if trading_thread is None or not trading_thread.is_alive():
        trading_thread = threading.Thread(target=main.start_trading)
        trading_thread.start()
    logging.info("Trading started via API.")
    return jsonify({"message": "거래가 성공적으로 시작되었습니다."})

@app.route('/stop_trading', methods=['POST'])
def stop_trading():
    main.stop_trading()
    if trading_thread is not None and trading_thread.is_alive():
        trading_thread.join()
    logging.info("Trading stopped via API.")
    return jsonify({"message": "거래가 성공적으로 중지되었습니다."})

@app.route('/analyze', methods=['POST'])
def analyze():
    main.collect_data()
    main.run_analysis()
    logging.info("Analysis and training started via API.")
    return jsonify({"message": "분석 및 학습이 시작되었습니다."})

if __name__ == "__main__":
    logging.info("Starting Flask server in debug mode")
    socketio.run(app, host='127.0.0.1', port=8000, debug=True)
    logging.info("Flask server started")
