
import os
import websocket
from .config_manager import ConfigManager, parse_mst_file

# Determine the base directory
base_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

class WebSocketClient:
    def __init__(self, url, kosdaq_data, kospi_data):
        self.url = url
        self.kosdaq_data = kosdaq_data
        self.kospi_data = kospi_data
        self.ws = None

    def on_message(self, ws, message):
        print(f"Received message: {message}")

    def on_error(self, ws, error):
        print(f"Error: {error}")

    def on_close(self, ws, close_status_code, close_msg):
        print(f"Closed connection: {close_msg}")

    def on_open(self, ws):
        print("Connection opened")

    def run(self):
        websocket.enableTrace(True)
        self.ws = websocket.WebSocketApp(
            self.url,
            on_message=self.on_message,
            on_error=self.on_error,
            on_close=self.on_close,
            on_open=self.on_open
        )
        self.ws.run_forever()

# Initialize ConfigManager
config_path = os.path.join(base_dir, 'config.yaml')
env_path = os.path.join(base_dir, '.env')
config_manager = ConfigManager(config_path, env_path)

# Parse the MST files
kosdaq_path = os.path.join(base_dir, 'config', 'kosdaq_code.mst')
kospi_path = os.path.join(base_dir, 'config', 'kospi_code.mst')
kosdaq_data = parse_mst_file(kosdaq_path)
kospi_data = parse_mst_file(kospi_path)

# Retrieve WebSocket URL from configuration
ws_url = config_manager.get('websocket.url', 'ws://localhost:8000')

# Initialize and run WebSocket client
ws_client = WebSocketClient(ws_url, kosdaq_data, kospi_data)
ws_client.run()
